@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Add 32nd, 64th and tuple durations to MIDI-Perl
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 use strict;
 use warnings;
 
@@ -22,12 +22,15 @@ use MIDI::Simple;
         # Compute the note duration.
         $MIDI::Simple::Length{$n} = $duration eq $last
             ? 4 : $MIDI::Simple::Length{ $last . 'n' } / 2;
+
         # Compute the dotted duration.
         $MIDI::Simple::Length{ 'd'  . $n } = $MIDI::Simple::Length{$n}
             + $MIDI::Simple::Length{$n} / 2;
+
         # Compute the double-dotted duration.
         $MIDI::Simple::Length{ 'dd' . $n } = $MIDI::Simple::Length{'d' . $n}
             + $MIDI::Simple::Length{$n} / 4;
+
         # Compute triplet duration.
         $MIDI::Simple::Length{ 't'  . $n } = $MIDI::Simple::Length{$n} / 3 * 2;
 
@@ -56,7 +59,7 @@ Music::Duration - Add 32nd, 64th and tuple durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -68,42 +71,54 @@ version 0.0601
   use MIDI::Simple;
   use Music::Duration;
 
-  # Create and set up a new_score...
+  Music::Duration::tuple( 'ten', 'z', 5 );
 
-  Music::Duration::tuple( 'qn', 'z', 5 );
-  n('zqn', 'n38') for 1 .. 5; # 5 snares in place of a standard quarter note
+  my $black_page = MIDI::Simple->new_score();
+  # ...
+  n( 'zten', 'n38' ) for 1 .. 5; # 5 snares in place of an eighth note triplet
 
 =head1 DESCRIPTION
 
 This module adds thirty-second and sixty-fourth note divisions to
-L<MIDI::Simple>.  These are 32nd: yn, dyn, ddyn, tyn and 64th: xn, dxn, ddxn,
-txn.
+L<MIDI::Simple>.  It also adds fractional note divisions with the B<tuple()>
+function.
 
-Also, this module allows the addition of non-standard note divisions with the
-B<tuple()> function.
+32nd durations added:
+
+  yn dyn ddyn tyn
+
+64th durations added:
+
+  xn dxn ddxn txn
 
 =head1 FUNCTION
 
 =head2 tuple()
 
+  Music::Duration::tuple( 'qn', 'z', 5 );
+  # $score->n( 'zqn', ... );
   Music::Duration::tuple( 'wn', 'z', 5 );
-  # Then: $score->n( 'zwn', ... );
+  # $score->n( 'zwn', ... );
 
-Add a fractional division for a given B<duration> of the L<MIDI::Simple>
-C<Length> hash.
+Add a fractional division to the L<MIDI::Simple> C<Length> hash for a given
+B<name> and B<duration>.
 
 Musically, this creates a "cluster" of notes in place of the given B<duration>.
 
-So instead of a whole note of four beats, we instead play 5 beats.  A triplet is
-a 3-tuple.
+A triplet is a 3-tuple.
+
+So in the first example, instead of a quarter note, we instead play 5 beats - a
+5-tuple.  In the second, instead of a whole note (of four beats), we instead
+play 5 beats.
 
 =head1 SEE ALSO
 
-The description of the C<Length> hash in the "Parameters for n/r/noop" section
-in L<MIDI::Simple>
+The C<Length> hash in L<MIDI::Simple>
 
 The code in the C<t/> directory
 
+L<https://www.scribd.com/doc/26974069/Frank-Zappa-The-Black-Page-1-Melody-Score>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
